@@ -8,15 +8,15 @@
 # efficient when running against very large numbers of instruments or portfolios.
 #
 # Copyright (c) 2008 Kris Boudt and Brian G. Peterson
-# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson for PerformanceAnalytics
+# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson for PerformanceAnalytics
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 ###############################################################################
-# $Id: MultivariateMoments.R 2214 2012-07-27 17:10:06Z braverock $
+# $Id: MultivariateMoments.R 3522 2014-09-02 21:09:55Z braverock $
 ###############################################################################
 
 
-M3.MM = function(R,...){
+M3.MM.old = function(R,...){
    cAssets = ncol(R); T = nrow(R);
    if(!hasArg(mu)) mu = apply(R,2,'mean') else mu=mu=list(...)$mu
    M3 = matrix(rep(0,cAssets^3),nrow=cAssets,ncol=cAssets^2)
@@ -28,7 +28,37 @@ M3.MM = function(R,...){
    return( 1/T*M3 );
 }
 
-M4.MM = function(R,...){
+#'@useDynLib PerformanceAnalytics
+#'@export
+#'@rdname CoMoments
+M3.MM = function(R, ...){
+  if(!hasArg(mu)) mu = colMeans(R) else mu=list(...)$mu
+  
+  # Pass variables directly from R to the Fortran subroutine
+  # Note that we also need to allocate the object that the Fortran subroutine
+  # returns
+  # It is ok to allocate objects in R and then pass to the Fortran subroutine
+  # https://stat.ethz.ch/pipermail/r-devel/2005-September/034570.html
+  x <- coredata(R)
+  
+  nr <- NROW(x)
+  nc <- NCOL(x)
+  
+  CC <- matrix(0, nc*nc, nc)
+  om <- matrix(0, nc, nc*nc)
+  
+  out <- .Fortran("M3",
+                  x=x,
+                  mu=as.double(mu),
+                  nr=as.integer(nr),
+                  nc=as.integer(nc),
+                  C=CC,
+                  om=om,
+                  PACKAGE="PerformanceAnalytics")$om
+  out
+}
+
+M4.MM.old = function(R,...){
    cAssets = ncol(R); T = nrow(R);
    if(!hasArg(mu))   mu = apply(R,2,'mean')  else mu=list(...)$mu
    M4 = matrix(rep(0,cAssets^4),nrow=cAssets,ncol=cAssets^3);
@@ -40,6 +70,35 @@ M4.MM = function(R,...){
    return( 1/T*M4 );
 }
 
+#'@useDynLib PerformanceAnalytics
+#'@export
+#'@rdname CoMoments
+M4.MM = function(R, ...){
+   if(!hasArg(mu)) mu = colMeans(R) else mu=list(...)$mu
+   
+  # Pass variables directly from R to the Fortran subroutine
+  # Note that we also need to allocate the object that the Fortran subroutine
+  # returns
+  # It is ok to allocate objects in R and then pass to the Fortran subroutine
+  # https://stat.ethz.ch/pipermail/r-devel/2005-September/034570.html
+  x <- coredata(R)
+  nr <- NROW(x)
+  nc <- NCOL(x)
+  
+  DD <- matrix(0, nc*nc*nc, nc)
+  om <- matrix(0, nc, nc*nc*nc)
+  
+  out <- .Fortran("M4",
+                  x=x,
+                  mu=as.double(mu),
+                  nr=as.integer(nr),
+                  nc=as.integer(nc),
+                  D=DD,
+                  om=om,
+                  PACKAGE="PerformanceAnalytics")$om
+  out
+}
+
 multivariate_mean = function(w,mu){
    return( t(w)%*%mu )
 }
@@ -142,11 +201,11 @@ SR.mES.MM = function(w, mu, sigma, M3 , M4 , p){
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson and Kris Boudt
+# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson and Kris Boudt
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: MultivariateMoments.R 2214 2012-07-27 17:10:06Z braverock $
+# $Id: MultivariateMoments.R 3522 2014-09-02 21:09:55Z braverock $
 #
 ###############################################################################
\ No newline at end of file
