@@ -58,7 +58,7 @@
 #' @references Keating, J. and Shadwick, W.F. The Omega Function. working
 #' paper. Finance Development Center, London. 2002. Kazemi, Schneeweis, and
 #' Gupta. Omega as a Performance Measure. 2003.
-#' @keywords ts multivariate distribution models
+###keywords ts multivariate distribution models
 #' @examples
 #' 
 #'     data(edhec)
@@ -143,7 +143,7 @@ function(R, L = 0, method = c("simple", "interp", "binomial", "blackscholes"), o
                 a = min(x)
                 b = max(x)
 
-                xcdf = Hmisc:::Ecdf.default(x, pl=FALSE)
+                xcdf = Hmisc::Ecdf.default(x, pl=FALSE)
                 f <- approxfun(xcdf$x,xcdf$y,method="linear",ties="ordered")
 
                 if(output == "full") {
@@ -184,11 +184,11 @@ function(R, L = 0, method = c("simple", "interp", "binomial", "blackscholes"), o
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: Omega.R 2163 2012-07-16 00:30:19Z braverock $
+# $Id: Omega.R 3528 2014-09-11 12:43:17Z braverock $
 #
 ###############################################################################
