@@ -30,7 +30,7 @@
 #' function
 #' @author Peter Carl
 #' @seealso \code{\link{clean.boudt}} \cr \code{\link{Return.Geltner}} \cr
-#' @keywords ts multivariate distribution models
+###keywords ts multivariate distribution models
 #' @examples
 #' 
 #' data(managers)
@@ -159,7 +159,7 @@ function(R, method = c("none","boudt","geltner"), alpha=.01, ...)
 #' }
 #' 
 #' Note that the primary value of data cleaning lies in creating a more robust
-#' and stable estimation of the distribution generating the large majority of
+#' and stable estimation of the distribution describing the large majority of
 #' the return data. The increased robustness and stability of the estimated
 #' moments utilizing cleaned data should be used for portfolio construction. If
 #' a portfolio manager wishes to have a more conservative risk estimate,
@@ -195,7 +195,7 @@ function(R, method = c("none","boudt","geltner"), alpha=.01, ...)
 #' Rousseeuw, P. J. (1985). Multivariate estimation with high breakdown point.
 #' In W. Grossmann, G. Pflug, I. Vincze, and W. Wertz (Eds.), Mathematical
 #' Statistics and Its Applications, Volume B, pp. 283?297. Dordrecht-Reidel.
-#' @keywords ts multivariate distribution models
+###keywords ts multivariate distribution models
 #' @export
 clean.boudt <-
 function(R, alpha=.01 , trim=1e-3)
@@ -211,7 +211,7 @@ function(R, alpha=.01 , trim=1e-3)
 
    T=dim(R)[1]; date=c(1:T)
    N=dim(R)[2];
-   MCD = covMcd(as.matrix(R),alpha=1-alpha)
+   MCD = robustbase::covMcd(as.matrix(R),alpha=1-alpha)
    mu = as.matrix(MCD$raw.center) #no reweighting
    sigma = MCD$raw.cov
    invSigma = solve(sigma);
@@ -258,11 +258,11 @@ function(R, alpha=.01 , trim=1e-3)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: Return.clean.R 2163 2012-07-16 00:30:19Z braverock $
+# $Id: Return.clean.R 3528 2014-09-11 12:43:17Z braverock $
 #
 ###############################################################################
