@@ -50,7 +50,7 @@
 #' @note Code inspired by a chart on:
 #' \url{http://zoonek2.free.fr/UNIX/48_R/03.html}
 #' @author Peter Carl
-#' @keywords ts multivariate distribution models hplot
+###keywords ts multivariate distribution models hplot
 #' @examples
 #' 
 #' data(edhec)
@@ -92,7 +92,7 @@ function (R, Rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
     # http://zoonek2.free.fr/UNIX/48_R/03.html
 
     if (method == "calc")  x = checkData(R, method = "zoo")
-    else x=t(R)
+    else x=R
     
     if(!is.null(dim(Rf)))
         Rf = checkData(Rf, method = "zoo")
@@ -122,10 +122,12 @@ function (R, Rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
         rnames = row.names(comparison)
     } else {
         # We have to make an assumption about the input here
-        x=t(x[,ncol(x):1])
+        #x=t(x[,ncol(x):1])
         returns = x[,1]
-        risk = x[,2]
-        rnames = names(returns)
+        risk = abs(x[,2])
+        rnames = rownames
+        ylab = colnames(x)[1]
+        xlab = colnames(x)[2]
     }
 
     # Set the charts to show the origin
@@ -135,7 +137,7 @@ function (R, Rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
         ylim = c(min(c(0,returns)), max(returns) + 0.02)
 
     if(add.boxplots){
-        original.layout <- par()
+        original.layout <- par(no.readonly=TRUE)
         layout( matrix( c(2,1,0,3), 2, 2, byrow=TRUE ),
                 c(1,6), c(4,1),
             )
@@ -205,11 +207,11 @@ function (R, Rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2012 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2014 Peter Carl and Brian G. Peterson
 #
 # This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.RiskReturnScatter.R 2287 2012-09-18 20:14:18Z braverock $
+# $Id: chart.RiskReturnScatter.R 3528 2014-09-11 12:43:17Z braverock $
 #
 ###############################################################################
